Skip to contents

RegistryTable$get_columns() is the typical way to get a RegistryColumn.

Public fields

key

String. Unique identifier within the table. Not globally unique.

def

Default value for new records.

upstream_type

Raw column type. Used to convert between R values and Registry values.

Methods


Method new()

Create a Registry column definition.

Usage

RegistryColumn$new(key, def, upstream_type)

Arguments

key

String. The column key.

def

The default value.

upstream_type

The raw column type.


Method print()

Print a human-readable representation of this column definition.

Usage

RegistryColumn$print()


Method clone()

The objects of this class are cloneable with this method.

Usage

RegistryColumn$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.