Skip to contents

Registry record value that failed validation.

Registry record value that failed validation.

See also

Public fields

raw_value

String. User-provided string representation of the invalid value.

May be "" (the empty string) if the value is missing but the column is required.

Methods


Method new()

Create a Registry invalid value.

Usage

RegistryInvalidValue$new(raw_value)

Arguments

raw_value

String. The underlying string value.


Method print()

Print a human-readable representation of this value.

Usage

RegistryInvalidValue$print()


Method clone()

The objects of this class are cloneable with this method.

Usage

RegistryInvalidValue$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.