Skip to contents

RegistryTable$list_records() is the typical way to get a RegistryRecord.

Public fields

id

String. Unique identifier.

Methods


Method new()

Get the representation of a specific record.

Usage

Arguments

id

String. The ID of the target record.


Method print()

Print a human-readable representation of this record.

Usage

RegistryRecord$print()


Method load()

(Re-)populate this record instance's cache.

Future calls to most getters will return immediately without making a network request.

Always makes a network request.

Usage

RegistryRecord$load()


Method get_name()

Get the name of this record.

Names are unique within a table. Names are not globally unique. Use id if a globally unique identifier is required.

Usage

RegistryRecord$get_name(load_if_missing = TRUE)

Arguments

load_if_missing

Logical.
If TRUE, load() the name if not in cache. If FALSE, return NULL if not in cache.

Returns

String value of the name.


Method get_columns()

Get the columns of this record's table.

Usage

RegistryRecord$get_columns(load_if_missing = TRUE)

Arguments

load_if_missing

Logical.
If TRUE, load() the columns if not in cache. If FALSE, return NULL if not in cache.

Returns

Named list mapping between column keys and the corresponding columns.


Method get_values()

Get this record's values.

The resulting dictionary is shared between all calls to this instance's get_values. Make deep copies if independent mutation is desired.

Usage

RegistryRecord$get_values(load_if_missing = TRUE)

Arguments

load_if_missing

Logical.
If TRUE, load() the values if not in cache. If FALSE, return NULL if not in cache.

Returns

Named list mapping between column keys and the corresponding values.


Method clone()

The objects of this class are cloneable with this method.

Usage

RegistryRecord$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.