In an execution context, this is the workspace in which the execution was run.
In the CLI context (when running latch commands) this is the
current setting of latch workspace, which defaults to the user's personal
workspace.
Value
Account for the current workspace.
See also
Other Accounts APIs:
Account