Registry project (folder containing Registry tables).
Source:R/registry_project.R
RegistryProject.RdAccount$list_registry_projects()
is the typical way to get a RegistryProject.
See also
Other Registry APIs:
RegistryColumn,
RegistryInvalidValue,
RegistryRecord,
RegistryTable
Methods
Method load()
(Re-)populate this project instance's cache.
Future calls to most getters will return immediately without making a network request.
Always makes a network request.
Method get_display_name()
Get the display name of this project.
This is an opaque string that can contain any valid Unicode data.
Display names are not unique and must never be used as identifiers.
Use id instead.
Arguments
load_if_missingLogical.
IfTRUE,load()the display name if not in cache. IfFALSE, returnNULLif not in cache.
Method list_tables()
List tables contained in this project.
Arguments
load_if_missingLogical.
IfTRUE,load()the table list if not in cache. IfFALSE, returnNULLif not in cache.
Returns
List of tables contained in this project.