RegistryTable$list_records()
is the typical way to get a RegistryRecord.
See also
Other Registry APIs:
RegistryColumn,
RegistryInvalidValue,
RegistryProject,
RegistryTable
Methods
Method load()
(Re-)populate this record instance's cache.
Future calls to most getters will return immediately without making a network request.
Always makes a network request.
Method get_name()
Get the name of this record.
Names are unique within a table. Names are not globally unique.
Use id if a globally unique identifier is required.
Arguments
load_if_missingLogical.
IfTRUE,load()the name if not in cache. IfFALSE, returnNULLif not in cache.
Method get_columns()
Get the columns of this record's table.
Arguments
load_if_missingLogical.
IfTRUE,load()the columns if not in cache. IfFALSE, returnNULLif not in cache.
Returns
Named list mapping between column keys and the corresponding columns.
Method get_values()
Get this record's values.
The resulting dictionary is shared between all calls to this
instance's get_values.
Make deep copies if independent mutation is desired.
Arguments
load_if_missingLogical.
IfTRUE,load()the values if not in cache. IfFALSE, returnNULLif not in cache.