RegistryProject$list_tables()
is the typical way to get a RegistryTable.
See also
Other Registry APIs:
RegistryColumn,
RegistryInvalidValue,
RegistryProject,
RegistryRecord
Methods
Method load()
(Re-)populate this table instance's cache.
Future calls to most getters will return immediately without making a network request.
Always makes a network request.
Method get_display_name()
Get the display name of this table.
This is an opaque string that can contain any valid Unicode data.
Display names are not unique and must never be used as identifiers.
Use id instead.
Arguments
load_if_missingLogical.
IfTRUE,load()the display name if not in cache. IfFALSE, returnNULLif not in cache.
Method get_columns()
Get the columns of this table.
Arguments
load_if_missingLogical.
IfTRUE,load()the columns if not in cache. IfFALSE, returnNULLif not in cache.
Returns
Named list of columns of this table.
Method list_records()
List records contained in this table.
Arguments
page_sizeNumber of records to return at a time
load_if_missingLogical.
IfTRUE,load()the records if not in cache. IfFALSE, returnNULLif not in cache.
Returns
coro::generator() returning pages of records from
this table.